@@ -9,11 +9,11 @@ SOURCE=$(dpkg-parsechangelog | sed -ne 's,Source: \(.*\),\1,p')
 SVNROOT=http://svn.code.sf.net/p/itext/code/tags/iText_$(echo $VERSION | sed -e s/\\./_/g)/itext
 
 DIR=itext
-TAR=../${SOURCE}_${VERSION}.orig.tar.gz
+TAR=../${SOURCE}_${VERSION}.orig.tar.xz
 
 svn export $SVNROOT $DIR
 find $DIR/src/test -name "*.pdf" -exec rm \{\} \;
-tar -cvzf $TAR $DIR
+tar -cvJf $TAR $DIR
 rm -rf $DIR
 
 # move to directory 'tarballs'
